@@ -52,6 +52,7 @@ int		tx_trailer_bits_len = 2;
 simpleaudio	*tx_sa_out;
 float		tx_bfsk_mark_f;
 unsigned int	tx_bit_nsamples;
+unsigned int	tx_flush_nsamples;
 
 void
 tx_stop_transmit_sighandler( int sig )
@@ -62,9 +63,8 @@ tx_stop_transmit_sighandler( int sig )
     for ( j=0; j<tx_trailer_bits_len; j++ )
 	simpleaudio_tone(tx_sa_out, tx_bfsk_mark_f, tx_bit_nsamples);
 
-    // 0.5 sec of zero samples to flush - FIXME lame
-    size_t sample_rate = simpleaudio_get_rate(tx_sa_out);
-    simpleaudio_tone(tx_sa_out, 0, sample_rate/2);
+    if ( tx_flush_nsamples )
+	simpleaudio_tone(tx_sa_out, 0, tx_flush_nsamples);
 
     tx_transmitting = 0;
 }
@@ -130,6 +130,10 @@ static void fsk_transmit_stdin(
     tx_sa_out = sa_out;
     tx_bfsk_mark_f = bfsk_mark_f;
     tx_bit_nsamples = bit_nsamples;
+    if ( tx_interactive )
+	tx_flush_nsamples = sample_rate/2; // 0.5 sec of zero samples to flush
+    else
+	tx_flush_nsamples = 0;
 
     // one-shot
     struct itimerval itv = {
@@ -142,6 +146,9 @@ static void fsk_transmit_stdin(
 	{0, 0}						// it_value
     };
 
+    // arbitrary chosen timeout value: 1/25 of a second
+    unsigned int idle_carrier_usec = (1000000/25);
+
     int block_input = tx_interactive && !txcarrier;
     if ( block_input )
 	signal(SIGALRM, tx_stop_transmit_sighandler);
@@ -159,8 +166,16 @@ static void fsk_transmit_stdin(
     {
         FD_ZERO(&fdset);
         FD_SET(fd, &fdset);
-        struct timeval tv_zero = { 0, 0 };
-        if( block_input || select(fd+1, &fdset, NULL, NULL, &tv_zero) )
+        struct timeval tv_idletimeout = { 0, 0 };
+
+	if ( !tx_interactive ) {
+	    // When stdin blocks we "emit idle tone", for a duration of
+	    // idle_carrier_usec.  If !tx_interactive (i.e. writing to an
+	    // audio file) make the select timeout the same duration.
+	    tv_idletimeout.tv_usec = idle_carrier_usec;
+	}
+
+        if( block_input || select(fd+1, &fdset, NULL, NULL, &tv_idletimeout) )
         {
 	    n_read = read(fd, &buf, sizeof(buf));
 	    if( n_read <= 0 ) //Includes EOF (0) and errors (-1)
@@ -211,10 +226,10 @@ static void fsk_transmit_stdin(
         else
         {
 	    tx_transmitting = 1;
-	    unsigned int j;
             /* emit idle tone (mark) */
-            for ( j=0; j<tx_leader_bits_len; j++ )
-                simpleaudio_tone(sa_out, invert_start_stop ? bfsk_space_f : bfsk_mark_f, sample_rate/50);
+	    simpleaudio_tone(sa_out,
+		    invert_start_stop ? bfsk_space_f : bfsk_mark_f,
+		    idle_carrier_usec * sample_rate / 1000000);
 	}
 
 	if ( block_input )
@@ -782,7 +797,7 @@ main( int argc, char*argv[] )
 	    bfsk_n_data_bits = 5;
 	if ( bfsk_nstopbits < 0 )
 	    bfsk_nstopbits = 1.5;
-    } else if ( strncasecmp(modem_mode, "tdd",3)==0 ) {
+    } else if ( strncasecmp(modem_mode, "tdd",4)==0 ) {
 	bfsk_databits_decode = databits_decode_baudot;
 	bfsk_databits_encode = databits_encode_baudot;
 	bfsk_data_rate = 45.45;
@@ -1111,7 +1126,7 @@ main( int argc, char*argv[] )
 	    assert ( samples_nvalid + read_nsamples <= samplebuf_size );
 	    ssize_t r;
 	    r = simpleaudio_read(sa, samples_readptr, read_nsamples);
-	    debug_log("simpleaudio_read(samplebuf+%zd, n=%zu) returns %zd\n",
+	    debug_log("simpleaudio_read(samplebuf+%td, n=%zu) returns %zd\n",
 		    samples_readptr - samplebuf, read_nsamples, r);
 	    if ( r < 0 ) {
 		fprintf(stderr, "simpleaudio_read: error\n");
@@ -1374,7 +1389,7 @@ main( int argc, char*argv[] )
 	if (bfsk_msb_first) {
 		bits = bit_reverse(bits, bfsk_n_data_bits);
 	}
-	debug_log("Input: %08x%08x - Databits: %i - Shift: %i\n", (unsigned int)(bits >> 32), (unsigned int)bits, bfsk_n_data_bits, bfsk_nstartbits);
+	debug_log("Input: %08x%08x - Databits: %u - Shift: %i\n", (unsigned int)(bits >> 32), (unsigned int)bits, bfsk_n_data_bits, bfsk_nstartbits);
 
 	unsigned int dataout_size = 4096;
 	char dataoutbuf[4096];
