@@ -55,6 +55,7 @@ typedef enum {
 simpleaudio *
 simpleaudio_open_stream(
 		sa_backend_t	sa_backend,
+		const char	*backend_device,
 		sa_direction_t	sa_stream_direction,
 		sa_format_t	sa_format,
 		unsigned int rate, unsigned int channels,
@@ -75,6 +76,9 @@ simpleaudio_get_format( simpleaudio *sa );
 unsigned int
 simpleaudio_get_samplesize( simpleaudio *sa );
 
+void
+simpleaudio_set_rxnoise( simpleaudio *sa, float rxnoise_factor );
+
 ssize_t
 simpleaudio_read( simpleaudio *sa, void *buf, size_t nframes );
 
@@ -96,6 +100,6 @@ void
 simpleaudio_tone(simpleaudio *sa_out, float tone_freq, size_t nsamples_dur);
 
 void
-simpleaudio_tone_init( unsigned int new_sin_table_len );
+simpleaudio_tone_init( unsigned int new_sin_table_len, float mag );
 
 #endif
